summaryrefslogtreecommitdiff
path: root/shell
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2014-03-26 16:37:00 +0100
committerStephan Bergmann <sbergman@redhat.com>2014-03-26 16:39:26 +0100
commit70cc2b191b95fbc210bc1f0f6a7159f341894f0f (patch)
treea70f4957c454b443520cbf91250c41d9eea80017 /shell
parent8757bea2e88c6e349e1fe98d8e9695d7b9c6179e (diff)
First batch of adding SAL_OVERRRIDE to overriding function declarations
...mostly done with a rewriting Clang plugin, with just some manual tweaking necessary to fix poor macro usage. Change-Id: I71fa20213e86be10de332ece0aa273239df7b61a
Diffstat (limited to 'shell')
-rw-r--r--shell/source/backends/desktopbe/desktopbackend.cxx20
-rw-r--r--shell/source/backends/gconfbe/gconfbackend.cxx20
-rw-r--r--shell/source/backends/kde4be/kde4backend.cxx20
-rw-r--r--shell/source/backends/kdebe/kdebackend.cxx20
-rw-r--r--shell/source/backends/localebe/localebackend.hxx20
-rw-r--r--shell/source/cmdmail/cmdmailmsg.hxx38
-rw-r--r--shell/source/cmdmail/cmdmailsuppl.hxx12
-rw-r--r--shell/source/sessioninstall/SyncDbusSessionHelper.hxx24
-rw-r--r--shell/source/unix/exec/shellexec.hxx8
-rw-r--r--shell/source/unix/sysshell/recently_used_file_handler.cxx16
10 files changed, 99 insertions, 99 deletions
diff --git a/shell/source/backends/desktopbe/desktopbackend.cxx b/shell/source/backends/desktopbe/desktopbackend.cxx
index 3b494ec39294..57851af87a0b 100644
--- a/shell/source/backends/desktopbe/desktopbackend.cxx
+++ b/shell/source/backends/desktopbe/desktopbackend.cxx
@@ -75,19 +75,19 @@ private:
virtual ~Default() {}
virtual OUString SAL_CALL getImplementationName()
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getDefaultImplementationName(); }
virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ServiceName == getSupportedServiceNames()[0]; }
virtual css::uno::Sequence< OUString > SAL_CALL
- getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception)
+ getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getDefaultSupportedServiceNames(); }
virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL
- getPropertySetInfo() throw (css::uno::RuntimeException, std::exception)
+ getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return css::uno::Reference< css::beans::XPropertySetInfo >(); }
virtual void SAL_CALL setPropertyValue(
@@ -96,20 +96,20 @@ private:
css::beans::UnknownPropertyException,
css::beans::PropertyVetoException,
css::lang::IllegalArgumentException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual css::uno::Any SAL_CALL getPropertyValue(
OUString const & PropertyName)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL addPropertyChangeListener(
OUString const &,
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removePropertyChangeListener(
@@ -117,7 +117,7 @@ private:
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL addVetoableChangeListener(
@@ -125,7 +125,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removeVetoableChangeListener(
@@ -133,7 +133,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
};
diff --git a/shell/source/backends/gconfbe/gconfbackend.cxx b/shell/source/backends/gconfbe/gconfbackend.cxx
index 2d908493f06d..71fbdd63137c 100644
--- a/shell/source/backends/gconfbe/gconfbackend.cxx
+++ b/shell/source/backends/gconfbe/gconfbackend.cxx
@@ -76,19 +76,19 @@ private:
virtual ~Service() {}
virtual OUString SAL_CALL getImplementationName()
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getServiceImplementationName(); }
virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ServiceName == getSupportedServiceNames()[0]; }
virtual css::uno::Sequence< OUString > SAL_CALL
- getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception)
+ getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getServiceSupportedServiceNames(); }
virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL
- getPropertySetInfo() throw (css::uno::RuntimeException, std::exception)
+ getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return css::uno::Reference< css::beans::XPropertySetInfo >(); }
virtual void SAL_CALL setPropertyValue(
@@ -97,20 +97,20 @@ private:
css::beans::UnknownPropertyException,
css::beans::PropertyVetoException,
css::lang::IllegalArgumentException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual css::uno::Any SAL_CALL getPropertyValue(
OUString const & PropertyName)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL addPropertyChangeListener(
OUString const &,
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removePropertyChangeListener(
@@ -118,7 +118,7 @@ private:
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL addVetoableChangeListener(
@@ -126,7 +126,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removeVetoableChangeListener(
@@ -134,7 +134,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
bool enabled_;
diff --git a/shell/source/backends/kde4be/kde4backend.cxx b/shell/source/backends/kde4be/kde4backend.cxx
index 8d6cfb1e429f..4670affff438 100644
--- a/shell/source/backends/kde4be/kde4backend.cxx
+++ b/shell/source/backends/kde4be/kde4backend.cxx
@@ -76,19 +76,19 @@ private:
virtual ~Service() {}
virtual OUString SAL_CALL getImplementationName()
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getServiceImplementationName(); }
virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ServiceName == getSupportedServiceNames()[0]; }
virtual css::uno::Sequence< OUString > SAL_CALL
- getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception)
+ getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getServiceSupportedServiceNames(); }
virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL
- getPropertySetInfo() throw (css::uno::RuntimeException, std::exception)
+ getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return css::uno::Reference< css::beans::XPropertySetInfo >(); }
virtual void SAL_CALL setPropertyValue(
@@ -97,20 +97,20 @@ private:
css::beans::UnknownPropertyException,
css::beans::PropertyVetoException,
css::lang::IllegalArgumentException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual css::uno::Any SAL_CALL getPropertyValue(
OUString const & PropertyName)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL addPropertyChangeListener(
OUString const &,
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removePropertyChangeListener(
@@ -118,7 +118,7 @@ private:
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL addVetoableChangeListener(
@@ -126,7 +126,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removeVetoableChangeListener(
@@ -134,7 +134,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
bool enabled_;
diff --git a/shell/source/backends/kdebe/kdebackend.cxx b/shell/source/backends/kdebe/kdebackend.cxx
index 50187a65d86a..96b5a441ebff 100644
--- a/shell/source/backends/kdebe/kdebackend.cxx
+++ b/shell/source/backends/kdebe/kdebackend.cxx
@@ -76,19 +76,19 @@ private:
virtual ~Service() {}
virtual OUString SAL_CALL getImplementationName()
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getServiceImplementationName(); }
virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
- throw (css::uno::RuntimeException, std::exception)
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ServiceName == getSupportedServiceNames()[0]; }
virtual css::uno::Sequence< OUString > SAL_CALL
- getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception)
+ getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return getServiceSupportedServiceNames(); }
virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL
- getPropertySetInfo() throw (css::uno::RuntimeException, std::exception)
+ getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return css::uno::Reference< css::beans::XPropertySetInfo >(); }
virtual void SAL_CALL setPropertyValue(
@@ -97,20 +97,20 @@ private:
css::beans::UnknownPropertyException,
css::beans::PropertyVetoException,
css::lang::IllegalArgumentException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual css::uno::Any SAL_CALL getPropertyValue(
OUString const & PropertyName)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL addPropertyChangeListener(
OUString const &,
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removePropertyChangeListener(
@@ -118,7 +118,7 @@ private:
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL addVetoableChangeListener(
@@ -126,7 +126,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removeVetoableChangeListener(
@@ -134,7 +134,7 @@ private:
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
bool enabled_;
diff --git a/shell/source/backends/localebe/localebackend.hxx b/shell/source/backends/localebe/localebackend.hxx
index 9288df3108ac..0e890018a3b8 100644
--- a/shell/source/backends/localebe/localebackend.hxx
+++ b/shell/source/backends/localebe/localebackend.hxx
@@ -40,15 +40,15 @@ class LocaleBackend : public ::cppu::WeakImplHelper2 <
// XServiceInfo
virtual OUString SAL_CALL
getImplementationName( )
- throw (uno::RuntimeException, std::exception) ;
+ throw (uno::RuntimeException, std::exception) SAL_OVERRIDE ;
virtual sal_Bool SAL_CALL
supportsService( const OUString& aServiceName )
- throw (uno::RuntimeException, std::exception) ;
+ throw (uno::RuntimeException, std::exception) SAL_OVERRIDE ;
virtual uno::Sequence<OUString> SAL_CALL
getSupportedServiceNames( )
- throw (uno::RuntimeException, std::exception) ;
+ throw (uno::RuntimeException, std::exception) SAL_OVERRIDE ;
/**
Provides the implementation name.
@@ -65,7 +65,7 @@ class LocaleBackend : public ::cppu::WeakImplHelper2 <
// XPropertySet
virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL
- getPropertySetInfo() throw (css::uno::RuntimeException, std::exception)
+ getPropertySetInfo() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return css::uno::Reference< css::beans::XPropertySetInfo >(); }
virtual void SAL_CALL setPropertyValue(
@@ -74,20 +74,20 @@ class LocaleBackend : public ::cppu::WeakImplHelper2 <
css::beans::UnknownPropertyException,
css::beans::PropertyVetoException,
css::lang::IllegalArgumentException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual css::uno::Any SAL_CALL getPropertyValue(
OUString const & PropertyName)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception);
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL addPropertyChangeListener(
OUString const &,
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removePropertyChangeListener(
@@ -95,7 +95,7 @@ class LocaleBackend : public ::cppu::WeakImplHelper2 <
css::uno::Reference< css::beans::XPropertyChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL addVetoableChangeListener(
@@ -103,7 +103,7 @@ class LocaleBackend : public ::cppu::WeakImplHelper2 <
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
virtual void SAL_CALL removeVetoableChangeListener(
@@ -111,7 +111,7 @@ class LocaleBackend : public ::cppu::WeakImplHelper2 <
css::uno::Reference< css::beans::XVetoableChangeListener > const &)
throw (
css::beans::UnknownPropertyException,
- css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+ css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{}
protected:
diff --git a/shell/source/cmdmail/cmdmailmsg.hxx b/shell/source/cmdmail/cmdmailmsg.hxx
index 5e5e3c04da08..b45226fc17e0 100644
--- a/shell/source/cmdmail/cmdmailmsg.hxx
+++ b/shell/source/cmdmail/cmdmailmsg.hxx
@@ -56,69 +56,69 @@ public:
virtual void SAL_CALL setBody( const OUString& aBody )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual OUString SAL_CALL getBody( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL setRecipient( const OUString& aRecipient )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual OUString SAL_CALL getRecipient( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL setCcRecipient( const ::com::sun::star::uno::Sequence< OUString >& aCcRecipient )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getCcRecipient( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL setBccRecipient( const ::com::sun::star::uno::Sequence< OUString >& aBccRecipient )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getBccRecipient( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL setOriginator( const OUString& aOriginator )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual OUString SAL_CALL getOriginator( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL setSubject( const OUString& aSubject )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual OUString SAL_CALL getSubject( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL setAttachement( const ::com::sun::star::uno::Sequence< OUString >& aAttachement )
- throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getAttachement( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XNameAccess
virtual ::com::sun::star::uno::Any SAL_CALL getByName( const OUString& aName )
- throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getElementNames( )
- throw (::com::sun::star::uno::RuntimeException, std::exception) ;
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE ;
virtual sal_Bool SAL_CALL hasByName( const OUString& aName )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XElementAccess
virtual ::com::sun::star::uno::Type SAL_CALL getElementType( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL hasElements( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
diff --git a/shell/source/cmdmail/cmdmailsuppl.hxx b/shell/source/cmdmail/cmdmailsuppl.hxx
index 0986932986ca..c90cfa4d1671 100644
--- a/shell/source/cmdmail/cmdmailsuppl.hxx
+++ b/shell/source/cmdmail/cmdmailsuppl.hxx
@@ -50,30 +50,30 @@ public:
virtual ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailClient > SAL_CALL querySimpleMailClient( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XSimpleMailClient
virtual ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailMessage > SAL_CALL createSimpleMailMessage( )
- throw (::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL sendSimpleMailMessage( const ::com::sun::star::uno::Reference< ::com::sun::star::system::XSimpleMailMessage >& xSimpleMailMessage, sal_Int32 aFlag )
- throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XServiceInfo
virtual OUString SAL_CALL getImplementationName( )
- throw(::com::sun::star::uno::RuntimeException, std::exception);
+ throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
- throw(::com::sun::star::uno::RuntimeException, std::exception);
+ throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames( )
- throw(::com::sun::star::uno::RuntimeException, std::exception);
+ throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
#endif
diff --git a/shell/source/unix/exec/shellexec.hxx b/shell/source/unix/exec/shellexec.hxx
index 33305e0ab44c..a4e4e4a6db46 100644
--- a/shell/source/unix/exec/shellexec.hxx
+++ b/shell/source/unix/exec/shellexec.hxx
@@ -46,20 +46,20 @@ public:
virtual void SAL_CALL execute( const OUString& aCommand, const OUString& aParameter, sal_Int32 nFlags )
- throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::system::SystemShellExecuteException, ::com::sun::star::uno::RuntimeException, std::exception);
+ throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::system::SystemShellExecuteException, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XServiceInfo
virtual OUString SAL_CALL getImplementationName( )
- throw(::com::sun::star::uno::RuntimeException, std::exception);
+ throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
- throw(::com::sun::star::uno::RuntimeException, std::exception);
+ throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames( )
- throw(::com::sun::star::uno::RuntimeException, std::exception);
+ throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
};
diff --git a/shell/source/unix/sysshell/recently_used_file_handler.cxx b/shell/source/unix/sysshell/recently_used_file_handler.cxx
index b5dbcc10cf7b..e6f7fad0193b 100644
--- a/shell/source/unix/sysshell/recently_used_file_handler.cxx
+++ b/shell/source/unix/sysshell/recently_used_file_handler.cxx
@@ -227,13 +227,13 @@ namespace /* private */ {
virtual void start_element(
const string_t& /*raw_name*/,
const string_t& local_name,
- const xml_tag_attribute_container_t& /*attributes*/)
+ const xml_tag_attribute_container_t& /*attributes*/) SAL_OVERRIDE
{
if ((local_name == TAG_RECENT_ITEM) && (NULL == item_))
item_ = new recently_used_item;
}
- virtual void end_element(const string_t& /*raw_name*/, const string_t& local_name)
+ virtual void end_element(const string_t& /*raw_name*/, const string_t& local_name) SAL_OVERRIDE
{
// check for end tags w/o start tag
if( local_name != TAG_RECENT_FILES && NULL == item_ )
@@ -255,23 +255,23 @@ namespace /* private */ {
current_element_.clear();
}
- virtual void characters(const string_t& character)
+ virtual void characters(const string_t& character) SAL_OVERRIDE
{
if (character != "\n")
current_element_ += character;
}
- virtual void start_document() {}
- virtual void end_document() {}
+ virtual void start_document() SAL_OVERRIDE {}
+ virtual void end_document() SAL_OVERRIDE {}
- virtual void ignore_whitespace(const string_t& /*whitespaces*/)
+ virtual void ignore_whitespace(const string_t& /*whitespaces*/) SAL_OVERRIDE
{}
virtual void processing_instruction(
- const string_t& /*target*/, const string_t& /*data*/)
+ const string_t& /*target*/, const string_t& /*data*/) SAL_OVERRIDE
{}
- virtual void comment(const string_t& /*comment*/)
+ virtual void comment(const string_t& /*comment*/) SAL_OVERRIDE
{}
private:
recently_used_item* item_;
diff --git a/shell/source/sessioninstall/SyncDbusSessionHelper.hxx b/shell/source/sessioninstall/SyncDbusSessionHelper.hxx
index 2cf5be1068c1..53a31a187903 100644
--- a/shell/source/sessioninstall/SyncDbusSessionHelper.hxx
+++ b/shell/source/sessioninstall/SyncDbusSessionHelper.hxx
@@ -23,30 +23,30 @@ namespace shell { namespace sessioninstall
SyncDbusSessionHelper(::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> const&);
virtual ~SyncDbusSessionHelper() {}
// XModify Methods
- virtual void SAL_CALL InstallPackageNames( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* packages */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception);
+ virtual void SAL_CALL InstallPackageNames( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* packages */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual void SAL_CALL InstallPackageFiles( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallPackageFiles( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallProvideFiles( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallProvideFiles( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallCatalogs( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallCatalogs( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallMimeTypes( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* mime_types */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallMimeTypes( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* mime_types */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallFontconfigResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallFontconfigResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallGStreamerResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallGStreamerResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* types */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallResources( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* types */, const ::com::sun::star::uno::Sequence< OUString >& /* resources */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL RemovePackageByFiles( SAL_UNUSED_PARAMETER ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL RemovePackageByFiles( SAL_UNUSED_PARAMETER ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
- virtual void SAL_CALL InstallPrinterDrivers( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL InstallPrinterDrivers( ::sal_uInt32 /* xid */, const ::com::sun::star::uno::Sequence< OUString >& /* files */, const OUString& /* interaction */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
// XQuery Methods
- virtual void SAL_CALL IsInstalled( const OUString& /* package_name */, const OUString& /* interaction */, ::sal_Bool& /* installed */ ) throw (::com::sun::star::uno::RuntimeException, std::exception);
+ virtual void SAL_CALL IsInstalled( const OUString& /* package_name */, const OUString& /* interaction */, ::sal_Bool& /* installed */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual void SAL_CALL SearchFile( const OUString& /* file_name */, const OUString& /* interaction */, ::sal_Bool& /* installed */, OUString& /* package_name */ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ virtual void SAL_CALL SearchFile( const OUString& /* file_name */, const OUString& /* interaction */, ::sal_Bool& /* installed */, OUString& /* package_name */ ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ throw ::com::sun::star::uno::RuntimeException(); } // not implemented
private: